#!/usr/bin/env python
# -*- coding: utf-8 -*-

"""
test_cpv2010arg

Tests for `cpv2010arg` module.
"""

from __future__ import unicode_literals
import unittest
import nose

import pyredatam.cpv2010arg


class Cpv2010argTestCase(unittest.TestCase):

    def test_feature(self):
        pass


if __name__ == '__main__':
    nose.run(defaultTest=__name__)
